# update-repo [![Codacy Badge](https://app.codacy.com/project/badge/Grade/3c2abd87173b4b60ade389fbd4ef8d86)](https://www.codacy.com/gh/ffreemt/update-repo/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=ffreemt/update-repo&amp;utm_campaign=Badge_Grade)[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)[![PyPI version](https://badge.fury.io/py/update-repo.svg)](https://badge.fury.io/py/update-repo)

Update git repo: clone if the repo does not exist; pull if the repo already exist.

## Installation

```python
pip install update-repo``` (```!pip install update-repo``` in jupyter notebook)

## Usage

```python
from upate_repo import update_repo
update_repo(repo_name)
```
